@@ -142,11 +142,10 @@ vte_pty_child_setup (VtePty *pty)
                 signal(n, SIG_DFL);
         }
 
-        int masterfd = priv->pty_fd;
+        auto masterfd = priv->pty_fd;
         if (masterfd == -1)
                 _exit(127);
 
-        /* Read the slave number and unlock it. */
         if (grantpt(masterfd) != 0) {
                 _vte_debug_print(VTE_DEBUG_PTY, "%s failed: %m", "grantpt");
                 _exit(127);
@@ -220,8 +219,7 @@ vte_pty_child_setup (VtePty *pty)
 		}
 	}
 
-	/* Close the original slave descriptor, unless it's one of the stdio
-	 * descriptors. */
+	/* Close the original FD, unless it's one of the stdio descriptors */
 	if (fd != STDIN_FILENO &&
 			fd != STDOUT_FILENO &&
 			fd != STDERR_FILENO) {
@@ -296,6 +294,9 @@ __vte_pty_merge_environ (char **envp,
 
         g_hash_table_replace (table, g_strdup ("VTE_VERSION"), g_strdup_printf ("%u", VTE_VERSION_NUMERIC));
 
+	/* Always set this ourself, not allowing replacing from envp */
+	g_hash_table_replace(table, g_strdup("COLORTERM"), g_strdup("truecolor"));
+
 	array = g_ptr_array_sized_new (g_hash_table_size (table) + 1);
         g_hash_table_iter_init(&iter, table);
         while (g_hash_table_iter_next(&iter, (void**) &name, (void**) &value)) {
